###############################################################
#Analysis of Structural Change over 1992-2008 in EU27 regions #
###############################################################

rm(list=ls(all=TRUE))

library(mgcv)
library(spdep)
library(spectralGP)
library(maptools)
library(gstat)
library (RColorBrewer)

source("sameRangeForMaps.r")

#Load dataset
load("datasetNUTS2_CE2010_EU27_forGRV_analysis")
load("spatialWeightMatrices_EUregions")

#For maps
#Read a shape file, plot the map and get centroid points
x <- readShapePoly("NUTS_RG_03M_2006.shp")

# read shape file for all europe
xEurope <- readShapePoly("MyEurope.shp")

#Codes of the regions in the shape file
codesReg <- x$NUTS_ID

#Codes of the regions in the sample
# eliminate LV and BG (is an outleir for the GRV estimations) the id for LV is 176  and BG (21:26)
#Code for NUTS
codeNUTS <- read.csv("codeNuts_CE2010.csv",header=TRUE,sep=",",na.strings="NA")

codeNUTS_27  <- data.frame(as.character(codeNUTS[,3][(codeNUTS[,15]==1)]))
colnames (codeNUTS_27)[1]  <- "NUTS2"
NUTS_27 <- (codeNUTS[,15]==1)

codeNUTS_27_new_all <- data.frame(codeNUTS_27)
colnames (codeNUTS_27_new_all)[1]  <- "NUTS2"
codeNUTS_27_all <- codeNUTS_27_new_all[,1]

codeNUTS_27_new <- data.frame(codeNUTS_27[-c(21:26, 176), ])
colnames (codeNUTS_27_new)[1]  <- "NUTS2"
codeNUTS_27_inSample <- codeNUTS_27_new[jjj,1]
codeOurSample <- codeNUTS_27_inSample

#Common regions (NUT2) in the two datasets
commonRegions <- is.element(codesReg,codeNUTS_27_all)
codeCommonRegions <- codesReg[commonRegions==1]

#Vector of positions of regions in shp file
NUTS_RG_03M_2003Order <- numeric(length(codesReg[commonRegions]))
positions <- 1:length(codesReg[commonRegions])
for (i in 1:length(codesReg[commonRegions])){
  NUTS_RG_03M_2003Order[i] <- positions[as.character(codeNUTS_27_all[i])==as.character(codesReg[commonRegions])]
}

#Consider only NUT2 regions in our order
x1  <- x[commonRegions,][NUTS_RG_03M_2003Order,]
codesRegOnlyNuts2 <- x1$NUTS_ID

#NUTS0 = countires
codeNUTS0_29 <- unique(codeNUTS$NUTS0)
noEU <- codeNUTS0_29=="CH" | codeNUTS0_29=="NO"
codeNUTS0_27_new_all <- codeNUTS0_29[noEU==F]

#Common regions (NUT0) in the two datasets
commonCountries <- is.element(codesReg,codeNUTS0_27_new_all)
codeCommonCountries <- codesReg[commonCountries==1]

#Vector of positions of countries in shp file
NUTS0_RG_03M_2003Order <- numeric(length(codesReg[commonCountries]))
positions <- 1:length(codesReg[commonCountries])
for (i in 1:length(codesReg[commonCountries])){
  NUTS0_RG_03M_2003Order[i] <- positions[as.character(codeNUTS0_27_new_all[i])==as.character(codesReg[commonCountries])]
}

#Consider only NUT0 regions in our order
x1.countries  <- x[commonCountries,][NUTS0_RG_03M_2003Order,]
codesRegOnlyNuts0 <- x1.countries$NUTS_ID




#Define variable
  GDPpw <- samplePerWorkerGDP_27
  
  GDPpwRel <- samplePerWorkerGDPRel_27
  colnames(GDPpwRel) <- c(1991:2008)
  
  GDPpwGR <- samplePerWorkerGDPGR_27

  numYears <- ncol(GDPpw)

  #Firtst and last year of the sample
  PROD.InitialYear.REL <- (GDPpwRel[,1])  
  PROD.FinalYear.REL <-  (GDPpwRel[,(numYears)])

  LogGDPpwRel_initialYear <- log(GDPpwRel[,1])    
    
  #Average growth rate of each single regions
  #NB: use geometric mean!!      
  gm_mean = function(a){prod(a+1)^(1/length(a))-1}
  averageGrowthRateSingleRegions <- apply(GDPpwGR, 1, gm_mean)

  #Load Human Capital data Eurostat-Pose
  hc_EU.Pose.df <- read.csv("humanCapitalRegNUTS2.csv",header=TRUE,sep=",",na.strings="NA")
  hc_EU.Pose <- data.matrix(hc_EU.Pose.df)
  hc_EU.Pose_oursample <- hc_EU.Pose[,c(5:22)]
 
  GDPpw_pooled <- unlist(c(GDPpw[,c(2:ncol(GDPpw))]))
  hc_index_pooled <- unlist(c(hc_EU.Pose_oursample[,c(2:ncol(hc_EU.Pose_oursample))]))
  invRate_pooled <- unlist(c(sampleInvestmentRate_27[,c(2:ncol(sampleInvestmentRate_27))]))
  empGr_pooled <- unlist(c(sampleTotalEmploymentGR_27))

  #Define Sectors

  agriculture <- as.matrix(shareAgri_27)
  mining_energy <- as.matrix(shareMining_27)
  manufacturing <- as.matrix(shareManu_27)
  construction <- as.matrix(shareConstruction_27)
  hotel_restaurant <- as.matrix(shareHotel_27)
  transport <- as.matrix(shareTransport_27)
  finance <- as.matrix(shareFinance_27)
  wholesails_retails <- as.matrix(shareWholesale_27)
  other_services <- as.matrix(shareOtherServices_27)
  non_market_services <- as.matrix(shareNoMarketServ_27)


  # agriculture <- shareAgriRel_27
  # mining_energy <- shareMiningRel_27
  # manufacturing <- shareManuRel_27
  # construction <- shareConstructionRel_27
  # hotel_restaurant <- shareHotelRel_27
  # transport <- shareTransportRel_27
  # finance <- shareFinanceRel_27
  # wholesails_retails <- shareWholesaleRel_27
  # other_services <- shareOtherServicesRel_27
  # non_market_services <- shareNoMarketServRel_27


  #Relation shareAgri and GDPpw (pooled all years)
  gam_GDPpw_shareAgri <- gam( c(agriculture) ~ s(unlist(log(GDPpw))))
  summary(gam_GDPpw_shareAgri)	
  fitted <- predict.gam(gam_GDPpw_shareAgri,se.fit=TRUE)
  ttt <- sort(unlist(log(GDPpw)), index.return=TRUE)$ix
 
  plot(unlist(log(GDPpw))[ttt], c(agriculture)[ttt],type="p",pch=19,cex=0.5, col="grey", xlab="GDP per worker (log)", ylab="Share of Agriculture sector") 
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_GDPpw_shareAgri.eps",width=9,height=9)
 
  #Map
  #Put NAs in out of sample regions
  notNARegions <- codeNUTS_27_all%in%codeOurSample
  agriculture_1991_all <- vector("numeric",length(notNARegions))
  agriculture_1991_all[notNARegions] <- agriculture[,1]
  agriculture_1991_all[notNARegions==F] <- NA
  agriculture_2008_all <- vector("numeric",length(notNARegions))
  agriculture_2008_all[notNARegions] <- agriculture[,ncol(agriculture)]
  agriculture_2008_all[notNARegions==F] <- NA

  quantile <- quantile(agriculture_1991_all, probs =  c(0, 0.25, 0.50, 0.75, 1), na.rm = T)
  quantile[5] <- max(c(agriculture_1991_all, agriculture_2008_all),na.rm=TRUE)
  ttt <- sameRangeForMaps(xxx= agriculture_1991_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareAgri_1991.eps")


  ttt <- sameRangeForMaps(xxx= agriculture_2008_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareAgri_2008.eps")


  
  	
  #Relation shareManu and GDPpw (pooled all years)
  gam_GDPpw_shareManu <- gam( c(manufacturing) ~ s(unlist(log(GDPpw))))
  summary(gam_GDPpw_shareManu)	
  fitted <- predict.gam(gam_GDPpw_shareManu,se.fit=TRUE)
  ttt <- sort(unlist(log(GDPpw)), index.return=TRUE)$ix
 
  plot(unlist(log(GDPpw))[ttt], c(manufacturing)[ttt],type="p",pch=19,cex=0.5, col="grey", xlab="GDP per worker (log)", ylab="Share of Manufacturing sector") 
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_GDPpw_shareManu.eps",width=9,height=9)
 
  #Map
  #Put NAs in out of sample regions
  notNARegions <- codeNUTS_27_all%in%codeOurSample
  manufacturing_1991_all <- vector("numeric",length(notNARegions))
  manufacturing_1991_all[notNARegions] <- manufacturing[,1]
  manufacturing_1991_all[notNARegions==F] <- NA
  manufacturing_2008_all <- vector("numeric",length(notNARegions))
  manufacturing_2008_all[notNARegions] <- manufacturing[,ncol(manufacturing)]
  manufacturing_2008_all[notNARegions==F] <- NA

  quantile <- quantile(manufacturing_1991_all, probs =  c(0, 0.25, 0.50, 0.75, 1), na.rm = T)
  quantile[5] <- max(c(manufacturing_1991_all, manufacturing_2008_all),na.rm=TRUE)
  ttt <- sameRangeForMaps(xxx= manufacturing_1991_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareManu_1991.eps")


  ttt <- sameRangeForMaps(xxx= manufacturing_2008_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareManu_2008.eps")





   #Relation shareCon and GDPpw (pooled all years)
  gam_GDPpw_shareCon <- gam( c(construction) ~ s(unlist(log(GDPpw))))
  summary(gam_GDPpw_shareCon)	
  fitted <- predict.gam(gam_GDPpw_shareCon,se.fit=TRUE)
  ttt <- sort(unlist(log(GDPpw)), index.return=TRUE)$ix
 
  plot(unlist(log(GDPpw))[ttt], c(construction)[ttt],type="p",pch=19,cex=0.5, col="grey", xlab="GDP per worker (log)", ylab="Share of Construction sector") 
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_GDPpw_shareCon.eps",width=9,height=9)
 
  #Map
  #Put NAs in out of sample regions
  notNARegions <- codeNUTS_27_all%in%codeOurSample
  construction_1991_all <- vector("numeric",length(notNARegions))
  construction_1991_all[notNARegions] <- construction[,1]
  construction_1991_all[notNARegions==F] <- NA
  construction_2008_all <- vector("numeric",length(notNARegions))
  construction_2008_all[notNARegions] <- construction[,ncol(construction)]
  construction_2008_all[notNARegions==F] <- NA

  quantile <- quantile(construction_1991_all, probs =  c(0, 0.25, 0.50, 0.75, 1), na.rm = T)
  quantile[5] <- max(c(construction_1991_all, construction_2008_all),na.rm=TRUE)
  ttt <- sameRangeForMaps(xxx= construction_1991_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareCon_1991.eps")


  ttt <- sameRangeForMaps(xxx= construction_2008_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareCon_2008.eps")


 
 
    #Relation shareFin and GDPpw (pooled all years)
  gam_GDPpw_shareFin <- gam( c(finance) ~ s(unlist(log(GDPpw))))
  summary(gam_GDPpw_shareFin)	
  fitted <- predict.gam(gam_GDPpw_shareFin,se.fit=TRUE)
  ttt <- sort(unlist(log(GDPpw)), index.return=TRUE)$ix
 
  plot(unlist(log(GDPpw))[ttt], c(finance)[ttt],type="p",pch=19,cex=0.5, col="grey", xlab="GDP per worker (log)", ylab="Share of Finance sector") 
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_GDPpw_shareFin.eps",width=9,height=9)
 
  #Map
  #Put NAs in out of sample regions
  notNARegions <- codeNUTS_27_all%in%codeOurSample
  finance_1991_all <- vector("numeric",length(notNARegions))
  finance_1991_all[notNARegions] <- finance[,1]
  finance_1991_all[notNARegions==F] <- NA
  finance_2008_all <- vector("numeric",length(notNARegions))
  finance_2008_all[notNARegions] <- finance[,ncol(finance)]
  finance_2008_all[notNARegions==F] <- NA

  quantile <- quantile(finance_1991_all, probs =  c(0, 0.25, 0.50, 0.75, 1), na.rm = T)
  quantile[5] <- max(c(finance_1991_all, finance_2008_all),na.rm=TRUE)
  ttt <- sameRangeForMaps(xxx= finance_1991_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareFin_1991.eps")


  ttt <- sameRangeForMaps(xxx= finance_2008_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareFin_2008.eps")


  	


    #Relation shareOtherServ and GDPpw (pooled all years)
  gam_GDPpw_shareOtherServ <- gam( c(other_services) ~ s(unlist(log(GDPpw))))
  summary(gam_GDPpw_shareOtherServ)	
  fitted <- predict.gam(gam_GDPpw_shareOtherServ,se.fit=TRUE)
  ttt <- sort(unlist(log(GDPpw)), index.return=TRUE)$ix
 
  plot(unlist(log(GDPpw))[ttt], c(other_services)[ttt],type="p",pch=19,cex=0.5, col="grey", xlab="GDP per worker (log)", ylab="Share of Other Services sector") 
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_GDPpw_shareOtherServ.eps",width=9,height=9)
 
  #Map
  #Put NAs in out of sample regions
  notNARegions <- codeNUTS_27_all%in%codeOurSample
  other_services_1991_all <- vector("numeric",length(notNARegions))
  other_services_1991_all[notNARegions] <- other_services[,1]
  other_services_1991_all[notNARegions==F] <- NA
  other_services_2008_all <- vector("numeric",length(notNARegions))
  other_services_2008_all[notNARegions] <- other_services[,ncol(other_services)]
  other_services_2008_all[notNARegions==F] <- NA

  quantile <- quantile(other_services_1991_all, probs =  c(0, 0.25, 0.50, 0.75, 1), na.rm = T)
  quantile[5] <- max(c(other_services_1991_all, other_services_2008_all),na.rm=TRUE)
  ttt <- sameRangeForMaps(xxx= other_services_1991_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareOtherServ_1991.eps")


  ttt <- sameRangeForMaps(xxx= other_services_2008_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareOtherServ_2008.eps")





    #Relation shareNonMarketServ and GDPpw (pooled all years)
  gam_GDPpw_shareNonMarketServ <- gam( c(non_market_services) ~ s(unlist(log(GDPpw))))
  summary(gam_GDPpw_shareNonMarketServ)	
  fitted <- predict.gam(gam_GDPpw_shareNonMarketServ,se.fit=TRUE)
  ttt <- sort(unlist(log(GDPpw)), index.return=TRUE)$ix
 
  plot(unlist(log(GDPpw))[ttt], c(non_market_services)[ttt],type="p",pch=19,cex=0.5, col="grey", xlab="GDP per worker (log)", ylab="Share of Non Market Services sector") 
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines(unlist(log(GDPpw))[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_GDPpw_shareNonMarketServ.eps",width=9,height=9)
 
  #Map
  #Put NAs in out of sample regions
  notNARegions <- codeNUTS_27_all%in%codeOurSample
  non_market_services_1991_all <- vector("numeric",length(notNARegions))
  non_market_services_1991_all[notNARegions] <- non_market_services[,1]
  non_market_services_1991_all[notNARegions==F] <- NA
  non_market_services_2008_all <- vector("numeric",length(notNARegions))
  non_market_services_2008_all[notNARegions] <- non_market_services[,ncol(non_market_services)]
  non_market_services_2008_all[notNARegions==F] <- NA

  quantile <- quantile(non_market_services_1991_all, probs =  c(0, 0.25, 0.50, 0.75, 1), na.rm = T)
  quantile[5] <- max(c(non_market_services_1991_all, non_market_services_2008_all),na.rm=TRUE)
  ttt <- sameRangeForMaps(xxx= non_market_services_1991_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareNonMarketServ_1991.eps")


  ttt <- sameRangeForMaps(xxx= non_market_services_2008_all,quantile_xxx=quantile,x.shape=x1,digit=2)
  submapCountries <- x1.countries

  colorQuantiles <- heat.colors(13,alpha=1)
  plot(xEurope, ,axes=F, 
  xlim=c(-10,35),ylim=c(35,70))
  plot(ttt$submapFirst,col="khaki1",border="Black",add=T)
  plot(ttt$submapSecond,col="burlywood1",border="Black",add=T)
  plot(ttt$submapThird,col="coral1",border="Black",add=T)
  plot(ttt$submapFourth,col="darkred",border="Black",add=T)
  plot(ttt$submapNA,col="grey",border="Black",add=T)

  plot(submapCountries,border="Black",lwd=2,add=T)

legend_map <- rbind(paste("[",ttt$classLimit1,")"),
                    paste("[",ttt$classLimit2,")"),
                    paste("[",ttt$classLimit3,")"),
                    paste("[",ttt$classLimit4,")"),
                    "NA"
)

legend("topleft",legend=legend_map,fill=c("khaki1","burlywood1","coral1 ","darkred","gray"),bty="n",cex=0.8)

dev.copy2eps(file="map_shareNonMarketServ_2008.eps")






#Structural Funds 1992-2008
fundsOB2OnGDP_II_III_IV  <- read.csv("fundsOB2OnGDP_II_III_IV.csv")

fundsOB2OnGDP_III <- fundsOB2OnGDP_II_III_IV[,2]
fundsOB2OnGDP_IV <- fundsOB2OnGDP_II_III_IV[,3]

#Period II 1994-1999, Period IV 2000-2006
years <- 1991:2008
DeltashareAgri_III <- agriculture[,which(years==1999)]-agriculture[,which(years==1994)]
DeltashareAgri_IV <- agriculture[,which(years==2006)]-agriculture[,which(years==2000)]

  #Relation fundsOB2OnGDP_III and DeltashareAgri_III 
  gam_DeltashareAgri_III_fundsOB2OnGDP_III <- gam(DeltashareAgri_III ~ s(fundsOB2OnGDP_III))
  summary(gam_DeltashareAgri_III_fundsOB2OnGDP_III)	
  fitted <- predict.gam(gam_DeltashareAgri_III_fundsOB2OnGDP_III,se.fit=TRUE)

  fundsOB2OnGDP_III_notNA <- fundsOB2OnGDP_III[!is.na(fundsOB2OnGDP_III)]
  DeltashareAgri_III_notNA <- DeltashareAgri_III[!is.na(fundsOB2OnGDP_III)]
  ttt <- sort(fundsOB2OnGDP_III_notNA, index.return=TRUE)$ix

  plot(fundsOB2OnGDP_III_notNA[ttt], DeltashareAgri_III_notNA[ttt], type="p",pch=19,cex=0.5, col="grey", xlab="Objective 2 funds on GDP over 1994-1999", ylab="Delta Share of Agriculture 1994-1999") 
  lines((fundsOB2OnGDP_III_notNA)[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines((fundsOB2OnGDP_III_notNA)[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines((fundsOB2OnGDP_III_notNA)[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_fundsOB2_DeltashareAgri_1994_1999.eps",width=9,height=9)



  #Relation fundsOB2OnGDP_IV and DeltashareAgri_IV 
  gam_DeltashareAgri_IV_fundsOB2OnGDP_IV <- gam(DeltashareAgri_IV ~ s(fundsOB2OnGDP_IV))
  summary(gam_DeltashareAgri_IV_fundsOB2OnGDP_IV)	
  fitted <- predict.gam(gam_DeltashareAgri_IV_fundsOB2OnGDP_IV,se.fit=TRUE)

  fundsOB2OnGDP_IV_notNA <- fundsOB2OnGDP_IV[!is.na(fundsOB2OnGDP_IV)]
  DeltashareAgri_IV_notNA <- DeltashareAgri_IV[!is.na(fundsOB2OnGDP_IV)]
  ttt <- sort(fundsOB2OnGDP_IV_notNA, index.return=TRUE)$ix

  plot(fundsOB2OnGDP_IV_notNA[ttt], DeltashareAgri_IV_notNA[ttt], type="p",pch=19,cex=0.5, col="grey", xlab="Objective 2 funds on GDP over 2000-2006", ylab="Delta Share of Agriculture 2000-2006",xlim=c(0,0.002),ylim=c(-0.5,0.5)) 
  lines((fundsOB2OnGDP_IV_notNA)[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines((fundsOB2OnGDP_IV_notNA)[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines((fundsOB2OnGDP_IV_notNA)[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_fundsOB2_DeltashareAgri_2000_2006.eps",width=9,height=9)




DeltashareMan_III <- manufacturing[,which(years==1999)]-manufacturing[,which(years==1994)]
DeltashareMan_IV <- manufacturing[,which(years==2006)]-manufacturing[,which(years==2000)]

  #Relation fundsOB2OnGDP_III and DeltashareMan_III 
  gam_DeltashareMan_III_fundsOB2OnGDP_III <- gam(DeltashareMan_III ~ s(fundsOB2OnGDP_III))
  summary(gam_DeltashareMan_III_fundsOB2OnGDP_III)	
  fitted <- predict.gam(gam_DeltashareMan_III_fundsOB2OnGDP_III,se.fit=TRUE)

  fundsOB2OnGDP_III_notNA <- fundsOB2OnGDP_III[!is.na(fundsOB2OnGDP_III)]
  DeltashareMan_III_notNA <- DeltashareMan_III[!is.na(fundsOB2OnGDP_III)]
  ttt <- sort(fundsOB2OnGDP_III_notNA, index.return=TRUE)$ix

  plot(fundsOB2OnGDP_III_notNA[ttt], DeltashareMan_III_notNA[ttt], type="p",pch=19,cex=0.5, col="grey", xlab="Objective 2 funds on GDP over 1994-1999", ylab="Delta Share of Manufacturing 1994-1999") 
  lines((fundsOB2OnGDP_III_notNA)[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines((fundsOB2OnGDP_III_notNA)[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines((fundsOB2OnGDP_III_notNA)[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_fundsOB2_DeltashareMan_1994_1999.eps",width=9,height=9)



  #Relation fundsOB2OnGDP_IV and DeltashareMan_IV 
  gam_DeltashareMan_IV_fundsOB2OnGDP_IV <- gam(DeltashareMan_IV ~ s(fundsOB2OnGDP_IV))
  summary(gam_DeltashareMan_IV_fundsOB2OnGDP_IV)	
  fitted <- predict.gam(gam_DeltashareMan_IV_fundsOB2OnGDP_IV,se.fit=TRUE)

  fundsOB2OnGDP_IV_notNA <- fundsOB2OnGDP_IV[!is.na(fundsOB2OnGDP_IV)]
  DeltashareMan_IV_notNA <- DeltashareMan_IV[!is.na(fundsOB2OnGDP_IV)]
  ttt <- sort(fundsOB2OnGDP_IV_notNA, index.return=TRUE)$ix

  plot(fundsOB2OnGDP_IV_notNA[ttt], DeltashareMan_IV_notNA[ttt], type="p",pch=19,cex=0.5, col="grey", xlab="Objective 2 funds on GDP over 2000-2006", ylab="Delta Share of Manufacturing 2000-2006",xlim=c(0,0.002),ylim=c(-0.4,0.4)) 
  lines((fundsOB2OnGDP_IV_notNA)[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines((fundsOB2OnGDP_IV_notNA)[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines((fundsOB2OnGDP_IV_notNA)[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_fundsOB2_DeltashareMan_2000_2006.eps",width=9,height=9)





DeltashareOtherServ_III <- other_services[,which(years==1999)]-other_services[,which(years==1994)]
DeltashareOtherServ_IV <- other_services[,which(years==2006)]-other_services[,which(years==2000)]

  #Relation fundsOB2OnGDP_III and DeltashareOtherServ_III 
  gam_DeltashareOtherServ_III_fundsOB2OnGDP_III <- gam(DeltashareOtherServ_III ~ s(fundsOB2OnGDP_III))
  summary(gam_DeltashareOtherServ_III_fundsOB2OnGDP_III)	
  fitted <- predict.gam(gam_DeltashareOtherServ_III_fundsOB2OnGDP_III,se.fit=TRUE)

  fundsOB2OnGDP_III_notNA <- fundsOB2OnGDP_III[!is.na(fundsOB2OnGDP_III)]
  DeltashareOtherServ_III_notNA <- DeltashareOtherServ_III[!is.na(fundsOB2OnGDP_III)]
  ttt <- sort(fundsOB2OnGDP_III_notNA, index.return=TRUE)$ix

  plot(fundsOB2OnGDP_III_notNA[ttt], DeltashareOtherServ_III_notNA[ttt], type="p",pch=19,cex=0.5, col="grey", xlab="Objective 2 funds on GDP over 1994-1999", ylab="Delta Share of Other Services 1994-1999") 
  lines((fundsOB2OnGDP_III_notNA)[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines((fundsOB2OnGDP_III_notNA)[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines((fundsOB2OnGDP_III_notNA)[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_fundsOB2_DeltashareOtherServ_1994_1999.eps",width=9,height=9)



  #Relation fundsOB2OnGDP_IV and DeltashareOtherServ_IV 
  gam_DeltashareOtherServ_IV_fundsOB2OnGDP_IV <- gam(DeltashareOtherServ_IV ~ s(fundsOB2OnGDP_IV))
  summary(gam_DeltashareOtherServ_IV_fundsOB2OnGDP_IV)	
  fitted <- predict.gam(gam_DeltashareOtherServ_IV_fundsOB2OnGDP_IV,se.fit=TRUE)

  fundsOB2OnGDP_IV_notNA <- fundsOB2OnGDP_IV[!is.na(fundsOB2OnGDP_IV)]
  DeltashareOtherServ_IV_notNA <- DeltashareOtherServ_IV[!is.na(fundsOB2OnGDP_IV)]
  ttt <- sort(fundsOB2OnGDP_IV_notNA, index.return=TRUE)$ix

  plot(fundsOB2OnGDP_IV_notNA[ttt], DeltashareOtherServ_IV_notNA[ttt], type="p",pch=19,cex=0.5, col="grey", xlab="Objective 2 funds on GDP over 2000-2006", ylab="Delta Share of Other Services 2000-2006",xlim=c(0,0.002),ylim=c(-0.3,0.3)) 
  lines((fundsOB2OnGDP_IV_notNA)[ttt],fitted$fit[ttt], lwd=3, col="black")
  lines((fundsOB2OnGDP_IV_notNA)[ttt],fitted$fit[ttt]+2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  lines((fundsOB2OnGDP_IV_notNA)[ttt],fitted$fit[ttt]-2*fitted$se.fit[ttt], lwd=2, col="black", lty="dotted")
  grid()
  
  dev.copy2eps(file="relation_fundsOB2_DeltashareOtherServ_2000_2006.eps",width=9,height=9)



